==> haskell-ansi-terminal-1.0.2-154.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal
version:              1.0.2
visibility:           public
id:                   ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt
key:                  ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  39e259c03efe537a7aa26d05e04e4bb5
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-FR1G7OvSAIl5TEdw9JuRHH:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ansi-terminal-1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ansi-terminal-1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ansi-terminal-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal
hs-libraries:         HSansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt
depends:
    ansi-terminal-types-0.11.5-FR1G7OvSAIl5TEdw9JuRHH base-4.18.2.1
    colour-2.3.6-H6QKK8UT9PiEnQ6wB0s1YD

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-1.0.2-156-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal
version:              1.0.2
visibility:           public
id:                   ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh
key:                  ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  d3760d4c756524c72fe307205a754648
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-4COH3669Yoo7naJje0KDG2:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ansi-terminal-1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ansi-terminal-1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ansi-terminal-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal
hs-libraries:         HSansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh
depends:
    ansi-terminal-types-0.11.5-4COH3669Yoo7naJje0KDG2 base-4.18.2.1
    colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
